@media (max-width :700px) {
  .content {
    max-width:100%

  }
  footer {
    width:100%;
    margin:0;
  }

  footer .info {
    width:100%;
  }

  footer .social-text {
    display:none;
  }

  footer .social {
    display:flex;
    width:50%;
    justify-content: space-around;
  }

  footer .love {
    margin-top: 1em;
  }
}
