<hr>
<footer>
  <div class="info">
    <div class="mail">
      <div>
        <p>
        {{site_title}}
        </p>
        <p>
        </p>
      </div>
    </div>

    <div class="social">
      <div>
        <a target="_blank" href="{{email_url}}">
          <span class="social-text">{{email_text}}</span>
          <i class="fa fa-envelope"></i>
        </a>
      </div>
      <div>

        <a target="_blank" href="{{twitter_url}}">
          <span class="social-text">Twitter</span>
          <i class="fab fa-twitter"></i>
        </a>
      </div>
      <div>

        <a target="_blank" href="{{gitlab_url}}">
          <span class="social-text">Gitlab</span>
          <i class="fab fa-gitlab"></i>
        </a>
      </div>
      <div>
        <a target="_blank" href="{{github_url}}">
          <span class="social-text">Github</span>
          <i class="fab fa-github"></i>
        </a>
      </div>
    </div>
  </div>
  <div class="love">
    made with <i class="fa fa-heart"></i>
    and <i class="fa fa-mug-hot"></i>
    by
    {{your_name}}
    with the help of
    <a href="{{generator_url}}">Journal Generator</a>
  </div>
</footer>
