{% extends 'base.html' %}
{% block title %} {{site_title}} {% endblock %}
{% block content %}
<div class="landing">
  <div class="post-list">
    {% for post in post_list %}
    <div class="post-list-item">
      <h1>
        <a href="{{post.href}}">
          {{post.title}}
        </a>
      </h1>
      <h5>
        <i>{{post.date}}</i>
      </h5>
    </div>
    {% endfor %}
  </div>
</div>
{% endblock %}
