{% extends 'base.html' %}
{% block title %}{{title}}{% endblock %}
{% block content %}
<div class="post">
    <h1>{{title}}</h1>
    <h5> <i>{{date}}</i> by {{your_name}}</h5>
    <div>
        {{body|safe}}
    </div>
</div>
{% endblock %}
